==> cattle_grid-0.2.1-py3-none-any.whl: cattle_grid/activity_pub/processing/test_remote.py <==
import json
import aiohttp
import pytest
import pydantic

from fast_depends import dependency_provider
from faststream.rabbit import RabbitBroker, TestRabbitBroker
from unittest.mock import AsyncMock, MagicMock
from collections import namedtuple

from cattle_grid.dependencies import get_client_session
from cattle_grid.activity_pub.actor import create_actor
from cattle_grid.testing.fixtures import database  # noqa

from cattle_grid.config.messaging import internal_exchange

from .remote import fetch_object, sending_message, resolve_inbox


@pytest.fixture
async def session():
    session_mock = AsyncMock(aiohttp.ClientSession)

    async def get_mock():
        yield session_mock

    dependency_provider.dependency_overrides[get_client_session] = get_mock

    return session_mock


@pytest.fixture
async def broker():
    br = RabbitBroker("amqp://guest:guest@localhost:5672/")
    br.subscriber("to_send", internal_exchange())(sending_message)
    br.subscriber("fetch_object", internal_exchange())(fetch_object)

    async with TestRabbitBroker(br, connect_only=False) as tbr:
        yield tbr


@pytest.fixture
async def test_actor():
    return await create_actor("http://localhost")


@pytest.mark.parametrize(
    "data",
    [
        {},
        {"actor": "http://alice"},
        {"uri": "http://object"},
    ],
)
async def test_fetch_invalid(broker, data):
    with pytest.raises(pydantic.ValidationError):
        await broker.publish(
            data,
            routing_key="fetch_object",
            exchange=internal_exchange(),
            rpc=True,
        )


async def test_fetch(broker, session, test_actor):
    expected = {"key": "value"}

    Result = namedtuple("http_result", ["status", "raise_for_status", "text"])

    result = Result(200, MagicMock(), AsyncMock(return_value=json.dumps(expected)))
    session.get = AsyncMock(return_value=result)

    import cattle_grid.dependencies.globals as g

    g.lookup = AsyncMock(return_value=MagicMock(result=None, uri="http://object"))

    response = await broker.publish(
        {"actor": test_actor.actor_id, "uri": "http://object"},
        routing_key="fetch_object",
        exchange=internal_exchange(),
        rpc=True,
    )

    session.get.assert_awaited_once()

    assert response == expected


async def test_to_send_no_inbox(broker, session, test_actor):
    Result = namedtuple("http_result", ["status", "raise_for_status", "text"])

    result = Result(
        200,
        MagicMock(),
        AsyncMock(return_value=json.dumps({})),
    )
    session.get = AsyncMock(return_value=result)
    session.post = AsyncMock(return_value=result)

    await broker.publish(
        {
            "actor": test_actor.actor_id,
            "target": "http://bob.test/actor",
            "data": {"type": "TestActivity"},
        },
        routing_key="to_send",
        exchange=internal_exchange(),
    )

    session.get.assert_awaited_once()
    session.post.assert_not_called()


async def test_to_send(broker, session, test_actor):
    Result = namedtuple("http_result", ["status", "raise_for_status", "text"])

    result = Result(
        200,
        MagicMock(),
        AsyncMock(return_value=json.dumps({"inbox": "http://bob.test/inbox"})),
    )
    session.get = AsyncMock(return_value=result)
    session.post = AsyncMock(return_value=result)

    await broker.publish(
        {
            "actor": test_actor.actor_id,
            "target": "http://bob.test/actor",
            "data": {"type": "TestActivity"},
        },
        routing_key="to_send",
        exchange=internal_exchange(),
    )

    session.get.assert_awaited_once()
    session.post.assert_called_once()


async def test_resolve_inbox_no_inbox():
    actor = AsyncMock()
    actor.get = AsyncMock(return_value={})

    result = await resolve_inbox(actor, "target")
    assert result is None


async def test_resolve_inbox():
    actor = AsyncMock()
    actor.get = AsyncMock(return_value={"inbox": "inbox"})

    result = await resolve_inbox(actor, "target")
    assert result == "inbox"

    actor.get.assert_awaited_once()

    # inbox is cached
    result = await resolve_inbox(actor, "target")
    actor.get.assert_awaited_once()

==> cattle_grid-0.2.8-py3-none-any.whl: cattle_grid/activity_pub/processing/test_remote.py <==
import json
import aiohttp
import pytest
import pydantic

from fast_depends import dependency_provider
from faststream.rabbit import RabbitBroker, TestRabbitBroker
from unittest.mock import AsyncMock, MagicMock
from collections import namedtuple

from cattle_grid.dependencies import get_client_session
from cattle_grid.activity_pub.actor import create_actor
from cattle_grid.testing.fixtures import *  # noqa

from cattle_grid.config.messaging import internal_exchange

from .remote import fetch_object, sending_message, resolve_inbox


@pytest.fixture
async def session():
    session_mock = AsyncMock(aiohttp.ClientSession)

    async def get_mock():
        yield session_mock

    dependency_provider.dependency_overrides[get_client_session] = get_mock

    return session_mock


@pytest.fixture
async def broker():
    br = RabbitBroker("amqp://guest:guest@localhost:5672/")
    br.subscriber("to_send", internal_exchange())(sending_message)
    br.subscriber("fetch_object", internal_exchange())(fetch_object)

    async with TestRabbitBroker(br, connect_only=False) as tbr:
        yield tbr


@pytest.fixture
async def test_actor():
    return await create_actor("http://localhost")


@pytest.mark.parametrize(
    "data",
    [
        {},
        {"actor": "http://alice"},
        {"uri": "http://object"},
    ],
)
async def test_fetch_invalid(broker, data):
    with pytest.raises(pydantic.ValidationError):
        await broker.publish(
            data,
            routing_key="fetch_object",
            exchange=internal_exchange(),
            rpc=True,
        )


async def test_fetch(broker, session, test_actor):
    expected = {"key": "value"}

    Result = namedtuple("http_result", ["status", "raise_for_status", "text"])

    result = Result(200, MagicMock(), AsyncMock(return_value=json.dumps(expected)))
    session.get = AsyncMock(return_value=result)

    import cattle_grid.dependencies.globals as g

    g.lookup = AsyncMock(return_value=MagicMock(result=None, uri="http://object"))

    response = await broker.publish(
        {"actor": test_actor.actor_id, "uri": "http://object"},
        routing_key="fetch_object",
        exchange=internal_exchange(),
        rpc=True,
    )

    session.get.assert_awaited_once()

    assert response == expected


async def test_to_send_no_inbox(broker, session, test_actor):
    Result = namedtuple("http_result", ["status", "raise_for_status", "text"])

    result = Result(
        200,
        MagicMock(),
        AsyncMock(return_value=json.dumps({})),
    )
    session.get = AsyncMock(return_value=result)
    session.post = AsyncMock(return_value=result)

    await broker.publish(
        {
            "actor": test_actor.actor_id,
            "target": "http://bob.test/actor",
            "data": {"type": "TestActivity"},
        },
        routing_key="to_send",
        exchange=internal_exchange(),
    )

    session.get.assert_awaited_once()
    session.post.assert_not_called()


async def test_to_send(broker, session, test_actor):
    Result = namedtuple("http_result", ["status", "raise_for_status", "text"])

    result = Result(
        200,
        MagicMock(),
        AsyncMock(return_value=json.dumps({"inbox": "http://bob.test/inbox"})),
    )
    session.get = AsyncMock(return_value=result)
    session.post = AsyncMock(return_value=result)

    await broker.publish(
        {
            "actor": test_actor.actor_id,
            "target": "http://bob.test/actor",
            "data": {"type": "TestActivity"},
        },
        routing_key="to_send",
        exchange=internal_exchange(),
    )

    session.get.assert_awaited_once()
    session.post.assert_called_once()


async def test_resolve_inbox_no_inbox():
    actor = AsyncMock()
    actor.get = AsyncMock(return_value={})

    result = await resolve_inbox(actor, "target")
    assert result is None


async def test_resolve_inbox():
    actor = AsyncMock()
    actor.get = AsyncMock(return_value={"inbox": "inbox"})

    result = await resolve_inbox(actor, "target")
    assert result == "inbox"

    actor.get.assert_awaited_once()

    # inbox is cached
    result = await resolve_inbox(actor, "target")
    actor.get.assert_awaited_once()
